from setuptools import setup

setup(name='python_challenge',
      version='0.2',
      description='Python module to find value in a binary tree',
      url='http://github.com/damolaajayi/python_challenge',
      author='Adedamola Ajayi',
      author_email='damolaajayi@gmail.com',
      license='MIT',
      packages=['python_challenge'],
      zip_safe=False,
      test_suite='nose.collector',
      tests_require=['nose'],
      )
